@@ -1,6 +1,6 @@
 package App::Greple::xlate;
 
-our $VERSION = "0.40";
+our $VERSION = "0.41";
 
 =encoding utf-8
 
@@ -16,7 +16,7 @@ App::Greple::xlate - translation support module for greple
 
 =head1 VERSION
 
-Version 0.40
+Version 0.41
 
 =head1 DESCRIPTION
 
@@ -113,7 +113,7 @@ text matching the second pattern.
 Therefore, use the first pattern for text that is to be processed by
 combining multiple lines into a single line, and use the second
 pattern for pre-formatted text.  If there is no text to match in the
-first pattern, then a pattern that does not match anything, such as
+first pattern, use a pattern that does not match anything, such as
 C<(?!)>.
 
 =head1 MASKING
@@ -410,6 +410,7 @@ Read Japanese article in L</SEE ALSO> section for detail.
         -s   silent mode
         -e # translation engine (default "deepl")
         -p # pattern to determine translation area
+        -x # file containing mask patterns
         -w # wrap line by # width
         -o # output format (default "xtxt", or "cm", "ifdef")
         -f # from lang (ignored)
@@ -425,14 +426,14 @@ Read Japanese article in L</SEE ALSO> section for detail.
         -B   run in non-interactive (batch) mode
         -R   mount read-only
         -E * specify environment variable to be inherited
-        -I * specify altanative docker image (default: tecolicom/xlate:version)
+        -I * docker image name or version (default: tecolicom/xlate:version)
         -D * run xlate on the container with the rest parameters
         -C * run following command on the container, or run shell
     
     Control Files:
         *.LANG    translation languates
-        *.FORMAT  translation foramt (xtxt, cm, ifdef)
-        *.ENGINE  translation engine (deepl or gpt3)
+        *.FORMAT  translation foramt (xtxt, cm, ifdef, colon, space)
+        *.ENGINE  translation engine (deepl, gpt3, gpt4, gpt4o)
 
 
 =head1 EMACS
@@ -763,7 +764,7 @@ sub strip {
     goto &paragraph_strip if $paragraph;
     my @text = $text =~ /.*\n|.+\z/g;
     my @space = map {
-	[ s/\A(\s+)// ? $1 : '', s/(\h+)$//  ? $1 : ''  ]
+	[ s/\A(\s+)// ? $1 : '', s/(\h+)$// ? $1 : '' ]
     } @text;
     $_[0] = join '', @text;
     sub { # unstrip
